@@ -21,7 +21,7 @@ use Math::BigInt;
 use Math::Random;
 use Fcntl 'SEEK_CUR';
 
-our $VERSION = '1.23';
+our $VERSION = '1.24';
 
 use overload  '+'        =>    '_join',
               '""'       =>    '_str',
@@ -1185,6 +1185,9 @@ bit arrays and for logical and arithmetic operations on such arrays.
 
 =head1 CHANGES
 
+Version 1.24 includes in the C<Makefile.PL> file the minimum version restriction on
+the C<List::Util> module that is imported.
+
 Version 1.23 mentions the required modules in the C<Makefile.PL> file but with no
 minimum version numbers.  Additionally, the documentation associated with the methods
 was significantly upgraded in this version.
@@ -1311,7 +1314,8 @@ This is made possible by the overload definition for the C<0+> operator.
     $bv3 = ~ $bv1;
     print $bv3;                                  # 000111
 
-This is made possible by the overload definition for the C<~> operator.
+This is made possible by the overload definition for the C<~> operator.  The original
+bitvector on which this unary operator is invoked remains unchanged.
 
 =item B<Taking logical OR of two bitvectors:>
 
@@ -1321,7 +1325,8 @@ When two bitvectors are of unequal length (as is the case here), the shorter vec
 is zero-padded on the left to equalize their lengths before the application of the
 logical operation.  If this auto-padding property is not something you want, you
 should check the lengths of the argument bitvectors in your own script before
-invoking this operator.
+invoking this operator. The result of the logical OR operation is returned as a new
+bitvector.  The two operand bitvectors remain unchanged.
 
 =item B<Taking logical AND of two bitvectors:>
 
@@ -1331,7 +1336,9 @@ When two bitvectors are of unequal length (as is the case here), the shorter vec
 is zero-padded on the left to equalize their lengths before the application of the
 logical operation. If this auto-padding property is not something you want, you
 should check the lengths of the argument bitvectors in your own script before
-invoking this operator.
+invoking this operator.  The result of the logical AND operation is returned as a new
+bitvector.  The two operand bitvectors remain unchanged.
+
 
 =item B<Taking logical XOR of two bitvectors:>
 
@@ -1341,7 +1348,9 @@ When two bitvectors are of unequal length (as is the case here), the shorter vec
 is zero-padded on the left to equalize their lengths before the application of the
 logical operation. If this auto-padding property is not something you want, you
 should check the lengths of the argument bitvectors in your own script before
-invoking this operator.
+invoking this operator.  The result of the logical XOR operation is returned as a new
+bitvector.  The two operand bitvectors remain unchanged.
+
 
 =item B<Comparing bitvectors:>
 
@@ -1358,9 +1367,9 @@ invoking this operator.
     $bv1 != $bv2 ?  print "yes\n"  :  print "no\n";       # yes
 
 The overload definitions for all these operators are autogenerated from the overload
-definition for the 3-way numerical comparison operator C<< <=> >>.  B<bitvectors are
-compared on the basis of their integer values.> That is, C<$bv1> is less than C<$bv2>
-is C<int($bv1)> is less than C<int($bv2)>.
+definition for the 3-way numerical comparison operator 'C<< <=> >>'.  B<The
+bitvectors are compared on the basis of their integer values.> That is, C<$bv1> is
+less than C<$bv2> if C<int($bv1)> is less than C<int($bv2)>.
 
 =item B<In-place circular shifting:>
 
@@ -2200,10 +2209,10 @@ the string 'BitVector' in the subject line.
 Download the archive from CPAN in any directory of your choice.  Unpack the archive
 with a command that on a Linux machine would look like:
 
-    tar zxvf Algorithm-BitVector-1.23.tar.gz
+    tar zxvf Algorithm-BitVector-1.24.tar.gz
 
 This will create an installation directory for you whose name will be
-C<Algorithm-BitVector-1.23>.  Enter this directory and execute the following commands
+C<Algorithm-BitVector-1.24>.  Enter this directory and execute the following commands
 for a standard install of the module if you have root privileges:
 
     perl Makefile.PL
